/*******************************************************************************
 * Copyright (c) 2010, 2014 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Lars Vogel <Lars.Vogel@gmail.com> - Bug 420836
 *******************************************************************************/

@import url("platform:/plugin/org.eclipse.ui.themes/css/common/e4_globalstyle.css");
@import url("platform:/plugin/org.eclipse.ui.themes/css/light/e4-light_globalstyle.css");
@import url("platform:/plugin/org.eclipse.ui.themes/css/light/e4-light_ide_colorextensions.css");
@import url("platform:/plugin/org.eclipse.ui.themes/css/light/e4-light_partstyle.css");
@import url("platform:/plugin/org.eclipse.ui.themes/css/light/e4-light_tabstyle.css");
@import url("platform:/plugin/org.eclipse.ui.themes/css/light/e4-light-drag-styling.css");
